==> pipewire-0.1.8-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/node_8h.js <==
var node_8h =
[
    [ "pw_node_events", "structpw__node__events.html", "structpw__node__events" ],
    [ "PW_NODE_PROP_AUTOCONNECT", "node_8h.html#af97e4e0860859339a98f01579c7df551", null ],
    [ "PW_NODE_PROP_TARGET_NODE", "node_8h.html#ab82160daf98a6cd3fb2383c8b44fbb67", null ],
    [ "PW_TYPE__Node", "node_8h.html#a3d0dd5f4051fd06f38d00aecbb03cfd1", null ],
    [ "PW_TYPE_NODE_BASE", "node_8h.html#a87e4a9a32213f0edb9e609a049dfdb25", null ],
    [ "PW_VERSION_NODE_EVENTS", "node_8h.html#a593a4f2610442e1956052f5c13de02f2", null ],
    [ "pw_node_add_listener", "node_8h.html#a2bb3fca14d3b5749df798bc517b02ae8", null ],
    [ "pw_node_destroy", "node_8h.html#a7ae451b0d2ce21ae7631563d804e0a8b", null ],
    [ "pw_node_find_port", "node_8h.html#ae457b2a0a17339a0ea724fb7248792d3", null ],
    [ "pw_node_for_each_port", "node_8h.html#aa54a8f52d35bd9521ceb32dc7e950a85", null ],
    [ "pw_node_get_core", "node_8h.html#aae589dae6a27dd5f2235d7108e3e8d9c", null ],
    [ "pw_node_get_free_port", "node_8h.html#aa9f3f6c6169457b6226ec79e5f6aba41", null ],
    [ "pw_node_get_free_port_id", "node_8h.html#ae040b5eb03ad653e474e1ef547adeeed", null ],
    [ "pw_node_get_global", "node_8h.html#abf5963060e24f9a496b6941a45f78bf1", null ],
    [ "pw_node_get_implementation", "node_8h.html#a43aca89a30f2cced48262819114baeb5", null ],
    [ "pw_node_get_info", "node_8h.html#acb7e0557ec2c7c95a18757dad387dd7c", null ],
    [ "pw_node_get_properties", "node_8h.html#a898e5e0afefe00d5154c9c1c64f84c53", null ],
    [ "pw_node_get_user_data", "node_8h.html#a13e057acc81dae7a8deb71a65ef326fb", null ],
    [ "pw_node_is_active", "node_8h.html#ae8556f1a5560c142b586096ad32844b5", null ],
    [ "pw_node_register", "node_8h.html#a36b815abe57af30ae54a94dbd59bbb20", null ],
    [ "pw_node_set_active", "node_8h.html#a2502272c5765d1f2dab5afd890c05f62", null ],
    [ "pw_node_set_implementation", "node_8h.html#a442d47d3b1668d9f57ade6109281a8c7", null ],
    [ "pw_node_update_properties", "node_8h.html#a01db9fe936ffca5e133a4f7acb699ca1", null ]
];

==> pipewire-0.1.9-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/node_8h.js <==
var node_8h =
[
    [ "pw_node_events", "structpw__node__events.html", "structpw__node__events" ],
    [ "PW_NODE_PROP_AUTOCONNECT", "node_8h.html#af97e4e0860859339a98f01579c7df551", null ],
    [ "PW_NODE_PROP_TARGET_NODE", "node_8h.html#ab82160daf98a6cd3fb2383c8b44fbb67", null ],
    [ "PW_TYPE__Node", "node_8h.html#a3d0dd5f4051fd06f38d00aecbb03cfd1", null ],
    [ "PW_TYPE_NODE_BASE", "node_8h.html#a87e4a9a32213f0edb9e609a049dfdb25", null ],
    [ "PW_VERSION_NODE_EVENTS", "node_8h.html#a593a4f2610442e1956052f5c13de02f2", null ],
    [ "pw_node_add_listener", "node_8h.html#a2bb3fca14d3b5749df798bc517b02ae8", null ],
    [ "pw_node_destroy", "node_8h.html#a7ae451b0d2ce21ae7631563d804e0a8b", null ],
    [ "pw_node_find_port", "node_8h.html#ae457b2a0a17339a0ea724fb7248792d3", null ],
    [ "pw_node_for_each_param", "node_8h.html#ab8554682ed331de13cc8a0632eeda3fe", null ],
    [ "pw_node_for_each_port", "node_8h.html#aa54a8f52d35bd9521ceb32dc7e950a85", null ],
    [ "pw_node_get_core", "node_8h.html#aae589dae6a27dd5f2235d7108e3e8d9c", null ],
    [ "pw_node_get_free_port", "node_8h.html#aa9f3f6c6169457b6226ec79e5f6aba41", null ],
    [ "pw_node_get_free_port_id", "node_8h.html#ae040b5eb03ad653e474e1ef547adeeed", null ],
    [ "pw_node_get_global", "node_8h.html#abf5963060e24f9a496b6941a45f78bf1", null ],
    [ "pw_node_get_implementation", "node_8h.html#a43aca89a30f2cced48262819114baeb5", null ],
    [ "pw_node_get_info", "node_8h.html#acb7e0557ec2c7c95a18757dad387dd7c", null ],
    [ "pw_node_get_properties", "node_8h.html#a898e5e0afefe00d5154c9c1c64f84c53", null ],
    [ "pw_node_get_user_data", "node_8h.html#a13e057acc81dae7a8deb71a65ef326fb", null ],
    [ "pw_node_is_active", "node_8h.html#ae8556f1a5560c142b586096ad32844b5", null ],
    [ "pw_node_is_enabled", "node_8h.html#a744c2f726f9305f6b04d3e92eb4232b6", null ],
    [ "pw_node_register", "node_8h.html#a36b815abe57af30ae54a94dbd59bbb20", null ],
    [ "pw_node_set_active", "node_8h.html#a2502272c5765d1f2dab5afd890c05f62", null ],
    [ "pw_node_set_enabled", "node_8h.html#a2c39fd06d78e6f0146e56a4571262fa9", null ],
    [ "pw_node_set_implementation", "node_8h.html#a442d47d3b1668d9f57ade6109281a8c7", null ],
    [ "pw_node_update_properties", "node_8h.html#a01db9fe936ffca5e133a4f7acb699ca1", null ]
];
